@@ -7,28 +7,24 @@
 
 module Command.Describe where
 
+import Common.Annex
 import Command
 import qualified Remote
-import UUID
-import Messages
+import Logs.UUID
 
-command :: [Command]
-command = [repoCommand "describe" (paramPair paramRemote paramDesc) seek
+def :: [Command]
+def = [command "describe" (paramPair paramRemote paramDesc) seek
 	"change description of a repository"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
 
-start :: CommandStartWords
-start ws = do
-	let (name, description) =
-		case ws of
-			(n:d) -> (n,unwords d)
-			_ -> error "Specify a repository and a description."
-	
+start :: [String] -> CommandStart
+start (name:description) = do
 	showStart "describe" name
 	u <- Remote.nameToUUID name
-	next $ perform u description
+	next $ perform u $ unwords description
+start _ = error "Specify a repository and a description."	
 
 perform :: UUID -> String -> CommandPerform
 perform u description = do
