@@ -9,6 +9,7 @@ module Types.BranchState where
 
 data BranchState = BranchState {
 	branchUpdated :: Bool, -- has the branch been updated this run?
+	indexChecked :: Bool, -- has the index file been checked to exist?
 
 	-- the content of one file is cached
 	cachedFile :: Maybe FilePath,
@@ -16,4 +17,4 @@ data BranchState = BranchState {
 }
 
 startBranchState :: BranchState
-startBranchState = BranchState False Nothing ""
+startBranchState = BranchState False False Nothing ""
